@@ -35,21 +35,21 @@ class Task(BaseTask):
         self.csslint_with_minjs = options.get('csslint_with_mincss', False)
         root_dir = os.path.normpath(os.path.dirname(__file__))
 
-        self.intepreter = options['csslint_interpreter'] or \
+        self.interpreter = options['csslint_interpreter'] or \
                           getattr(settings, 'CSSLINT_INTERPRETER', None)
-        if not self.intepreter:
-            self.intepreter = find_first_existing_executable(
-                [('nodejs', '--help'), ('rhino', '--help')])
-            if not self.intepreter:
+        if not self.interpreter:
+            self.interpreter = find_first_existing_executable(
+                [('node', '--help'), ('rhino', '--help')])
+            if not self.interpreter:
                 raise ValueError('No sutable js interpreter found. Please install nodejs or rhino')
 
         self.implementation = options['csslint_implementation']
         if not self.implementation:
-            runner = os.path.basename(self.intepreter)
+            runner = os.path.basename(self.interpreter)
             if 'rhino' in runner:
                 self.implementation = os.path.join(root_dir, 'csslint', 'release', 'csslint-rhino.js')
-            elif 'nodejs' in runner:
-                self.implementation = os.path.join(root_dir, 'csslint', 'release', 'csslint-node.js')
+            elif 'node' in runner:
+                self.implementation = os.path.join(root_dir, 'csslint', 'release', 'npm', 'cli.js')
             else:
                 raise ValueError('No sutable css lint runner found for %s' % self.interpreter)
                 
@@ -71,7 +71,7 @@ class Task(BaseTask):
             fmt = 'text'
 
         if files:
-            cmd = [self.intepreter, self.implementation, '--format=%s' % fmt] + files
+            cmd = [self.interpreter, self.implementation, '--format=%s' % fmt] + files
 
             process = subprocess.Popen(cmd, stdout=subprocess.PIPE)
             output, err = process.communicate()
@@ -81,7 +81,7 @@ class Task(BaseTask):
 
             self.output.write(output)
         elif self.to_file:
-            self.output.write('<csslint></csslint')
+            self.output.write('<?xml version="1.0" encoding="utf-8"?><lint></lint>')
 
     def static_files_iterator(self):
         locations = get_apps_locations(self.test_labels, self.test_all)
