@@ -7,13 +7,15 @@ TEMPLATE_DEBUG=DEBUG
 ROOT_URLCONF = 'test_app.urls'
 
 TEMPLATE_LOADERS = (
-    'django.template.loaders.app_directories.load_template_source',
+    'django.template.loaders.filesystem.Loader',
+    'django.template.loaders.app_directories.Loader',
 )
 
 PROJECT_APPS = (
     'django.contrib.sessions', # just to ensure that dotted apps test works
     'django_jenkins',
     'test_app',
+    'test_app_dirs',
 )
 
 INSTALLED_APPS = (
@@ -31,12 +33,14 @@ DATABASES = {
 JENKINS_TASKS = (
     'django_jenkins.tasks.with_coverage',
     'django_jenkins.tasks.django_tests',
+    'django_jenkins.tasks.dir_tests',
     'django_jenkins.tasks.run_pep8',
     'django_jenkins.tasks.run_pyflakes',
     'django_jenkins.tasks.run_jslint',
     'django_jenkins.tasks.run_csslint',    
     'django_jenkins.tasks.run_sloccount',    
     'django_jenkins.tasks.lettuce_tests',
+    'django_jenkins.tasks.with_local_celery',
 )
 
 JSLINT_CHECKED_FILES = [os.path.join(PROJECT_ROOT, 'static/js/test.js')]
@@ -45,3 +49,25 @@ CSSLINT_CHECKED_FILES = [os.path.join(PROJECT_ROOT, 'static/css/test.css')]
 # python > 2.4
 if sys.version_info[1] > 4:
     JENKINS_TASKS += ('django_jenkins.tasks.run_pylint',)
+
+
+STATIC_URL = '/media/'
+
+
+LOGGING = {
+    'version': 1,
+    'disable_existing_loggers': False,
+    'handlers': {
+        'console':{
+            'level':'DEBUG',
+            'class':'logging.StreamHandler',
+        },
+    },
+    'loggers': {
+        'django.request': {
+            'handlers': ['console'],
+            'level': 'ERROR',
+            'propagate': True,
+        },
+    }
+}
